Learn R Programming

mosaicCore (version 0.8.0)

formularise: Convert lazy objects into formulas

Description

Convert lazy objects into a formula

Usage

formularise(lazy_formula, envir = parent.frame())

Arguments

lazy_formula

an object of class lazy

envir

an environment that will be come the environment of the returned formula

Value

a formula

Details

The expression of the lazy object is evaluated in its environment. If the result is not a formula, then the formula is created with an empty left hand side and the expression on the right hand side.

Examples

Run this code
# NOT RUN {
formularise(rlang::quo(foo))
formularise(rlang::quo(y ~ x))
bar <- a ~ b
formularise(rlang::quo(bar))
# }

Run the code above in your browser using DataLab