powered by
return a vector of row or column indices
columns(x, default = c())rows(x, default = c())
rows(x, default = c())
an object that may or may not have any rows or columns
what to return if there are no rows or columns
if x has rows or columns, a vector of indices, else default
x
default
# NOT RUN { dim(iris) columns(iris) rows(iris) columns(NULL) columns("this doesn't have columns") # }
Run the code above in your browser using DataLab